==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-tools/packages/runtime-tools-process-webapp-components/src/JobsManagement/JobsManagementContextProvider.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import * as React from "react";
import { ApolloClient } from "apollo-client";
import JobsManagementContext from "./JobsManagementContext";
import { JobsManagementGatewayApiImpl } from "./JobsManagementGatewayApi";
import { GraphQLJobsManagementQueries } from "./JobsManagementQueries";

interface IOwnProps {
  apolloClient: ApolloClient<any>;
  children: React.ReactElement;
}

export const JobsManagementContextProvider: React.FC<IOwnProps> = ({ apolloClient, children }) => {
  return (
    <JobsManagementContext.Provider
      value={new JobsManagementGatewayApiImpl(new GraphQLJobsManagementQueries(apolloClient))}
    >
      {children}
    </JobsManagementContext.Provider>
  );
};

export default JobsManagementContextProvider;

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-tools/packages/runtime-tools-process-webapp-components/src/JobsManagement/JobsManagementContextProvider.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React, { useMemo } from "react";
import { ApolloClient } from "apollo-client";
import JobsManagementContext from "./JobsManagementContext";
import { JobsManagementGatewayApiImpl } from "./JobsManagementGatewayApi";
import { GraphQLJobsManagementQueries } from "./JobsManagementQueries";

interface IOwnProps {
  apolloClient: ApolloClient<any>;
  children: React.ReactElement;
}

export const JobsManagementContextProvider: React.FC<IOwnProps> = ({ apolloClient, children }) => {
  const gatewayApi = useMemo(
    () => new JobsManagementGatewayApiImpl(new GraphQLJobsManagementQueries(apolloClient)),
    [apolloClient]
  );
  return <JobsManagementContext.Provider value={gatewayApi}>{children}</JobsManagementContext.Provider>;
};

export default JobsManagementContextProvider;
